patch_headers — MSUMastro toolbox 0.1 documentation

# patch_headers

`msumastro.header_processing.patchers.` `patch_headers`(dir=None, new_file_ext=None, save_location=None, overwrite=False, purge_bad=True, add_time=True, add_apparent_pos=True, add_overscan=True, fix_imagetype=True)

  Add minimal information to Feder FITS headers.

  Parameters: | dir : str, optional Directory containing the files to be patched. Default is the current directory, `.` new_file_ext : str, optional Name added to the FITS files with updated header information. It is added to the base name of the input file, between the old file name and the .fit or .fits extension. Default is ‘new’. save_location : str, optional Directory to which the patched files should be written, if not dir. overwrite : bool, optional Set to True to replace the original files. purge_bad : bool, optional Remove “bad” keywords form header before any other processing. See `purge_bad_keywords()` for details. add_time : bool, optional If `True`, add time information (e.g. JD, LST); see `add_time_info()` for details. add_apparent_pos : bool, optional If `True`, add apparent position (e.g. alt/az) to headers. See `add_object_pos_airmass()` for details. add_overscan : bool, optional If `True`, add overscan keywords to the headers. See `add_overscan_header()` for details. fix_imagetype : bool, optional If `True`, change image types to IRAF-style. See `change_imagetype_to_IRAF()` for details.